Open
Bug 1924315
Opened 2 years ago
Updated 1 year ago
Nightly is 2x slower than Chrome on a FFT-image-comparison tool (Continuous GCMinor all with reason = FULL_SLOT_BUFFER)
Categories
(Core :: JavaScript Engine, task, P3)
Core
JavaScript Engine
Tracking
()
NEW
People
(Reporter: mayankleoboy1, Unassigned)
References
(Blocks 2 open bugs, )
Details
- Go to https://turbomaze.github.io/JS-Fourier-Image-Analysis/
- In the "image URL" field, paste this link : https://upload.wikimedia.org/wikipedia/commons/6/60/Bringer_of_War_Planet.png
- Click on "Draw"
- Click on "Compute 2D DFT"
- Click on "Reconstruct Image"
- Click on "See Difference"
Nightly; https://share.firefox.dev/4eM8sNx (12s, 12s, 300ms)
Chrome: https://share.firefox.dev/3U8Z5PH (6s, 6s, 250ms)
As an additional data point, I also used a 4096x4096 image. Here are the results:
Nightly:
Creating the DFT: https://share.firefox.dev/3BEOju1 (60s without the profiler)
reconstruct image: https://share.firefox.dev/3Ym7X7e (68s)
Diff: https://share.firefox.dev/401P4rj (1.5s)
Chrome:
Creating the DFT: 25s
Reconstruct image: 45s
Diff: 3s
Updated•2 years ago
|
| Reporter | ||
Comment 1•1 year ago
|
||
Latest profile: https://share.firefox.dev/4m01ojt
(not much change from the first comment)
You need to log in
before you can comment on or make changes to this bug.
Description
•